@@ -180,7 +180,7 @@ where
                 return Ok(node.idx)
              }
             }
-        println!("Note: Unable to find {} in the tree.",name);
+        info!("Note: Unable to find {} in the tree.",name);
         Err(0)
     }
     /// Get the index of the root.
@@ -1139,7 +1139,20 @@ pub fn bilan_mappings(sp_tree: &mut ArenaTree<String>,
                 shift_y = shift_y + incr;
                 shift_right_x = shift_right_x - incr;
             },
-            _=> {},
+            _=> { //Any other event
+                let x = gene_trees[*index_node].arena[*node].x;
+                let x = match bool_left {
+                    true   => x + PIPEBLOCK*shift_left_x / ratio,
+                    false  => x + PIPEBLOCK*shift_right_x / ratio,
+                };
+                gene_trees[*index_node].arena[*node].set_x_noref(x);
+                let y = gene_trees[*index_node].arena[*node].y;
+                let y = y + PIPEBLOCK*shift_y / ratio;
+                gene_trees[*index_node].arena[*node].set_y_noref(y);
+                shift_left_x = shift_left_x + incr;
+                shift_y = shift_y + incr;
+                shift_right_x = shift_right_x - incr;
+            },
         }
     }
     let children =  &mut  sp_tree.arena[index].children;
@@ -1193,24 +1206,20 @@ pub fn move_species_mappings(sp_tree: &mut ArenaTree<String>,
                                // let mut nodes = &mut sp_tree.arena[index].nodes;
                                // nodes.reverse();
     for (index_node, node) in &sp_tree.arena[index].nodes {
-        info!("[move_dupli_mappings] >>> {:?} {:?}",gene_trees[*index_node].arena[*node].name,
+        info!("[move_species_mappings] >>> {:?} {:?}",gene_trees[*index_node].arena[*node].name,
          gene_trees[*index_node].arena[*node].e);
         match  gene_trees[*index_node].arena[*node].e {
             Event::Speciation => {
-                // println!("ARGGFAGFAGFGEFGEFEGFEGEFG {:?}",gene_trees[*index_node].arena[*node]);
                 // on a une speciation
                 let species_children =  &mut  gene_trees[*index_node].arena[*node].children;
                 let mut left = species_children[0];
                 let mut right = species_children[1];
-                // println!("ARGNODeS  {:?}",sp_tree.arena[index].nodes);
                 // verifi si les enfant sont dans le meme noeud
                 if (sp_tree.arena[index].nodes.contains(&(*index_node,left))) &&
                    (sp_tree.arena[index].nodes.contains(&(*index_node,right))) {
-                    println!("ARGGFAGFAGFGEFGEFEGFEGEFGEFEG");
                     let mut left_x = gene_trees[*index_node].arena[left].x;
                     let mut right_x = gene_trees[*index_node].arena[right].x;
                     if left_x > right_x {
-                        println!("IBERSION");
                         let buf = left;
                         left = right;
                         right = buf;
@@ -1220,14 +1229,12 @@ pub fn move_species_mappings(sp_tree: &mut ArenaTree<String>,
                     };
                     let parent_x = gene_trees[*index_node].arena[*node].x;
                     if left_x > parent_x {
-                        println!("INVERTING LEFT at {:?}",gene_trees[*index_node].arena[*node]);
                     // gene_trees[*index_node].arena[*node].set_x_noref(left_x);
                     // gene_trees[*index_node].arena[left].set_x_noref(parent_x);
                      gene_trees[*index_node].arena[*node].set_x_noref((left_x + right_x) /2.0 );
                 }
 
                 if parent_x > right_x {
-                        println!("INVERTING RIGHT at {:?}",gene_trees[*index_node].arena[*node]);
                     // gene_trees[*index_node].arena[*node].set_x_noref(right_x);
                     // gene_trees[*index_node].arena[right].set_x_noref(parent_x);
                     gene_trees[*index_node].arena[*node].set_x_noref((left_x + right_x) /2.0 );
